package com.bonus.canteen.core.cook.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
//import com.bonus.canteen.core.cook.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.canteen.core.cook.domain.CookEvaluaOrder;
import com.bonus.canteen.core.cook.service.ICookEvaluaOrderService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 订单评价Controller
 * 
 * @author xsheng
 * @date 2025-05-25
 */
@Api(tags = "订单评价接口")
@RestController
@RequestMapping("/cook_evalua_order")
public class CookEvaluaOrderController extends BaseController {
    @Autowired
    private ICookEvaluaOrderService cookEvaluaOrderService;

    /**
     * 查询订单评价列表
     */
    @ApiOperation(value = "查询订单评价列表")
    //@RequiresPermissions("cook:order:list")
    @GetMapping("/list")
    public TableDataInfo list(CookEvaluaOrder cookEvaluaOrder) {
        startPage();
        List<CookEvaluaOrder> list = cookEvaluaOrderService.selectCookEvaluaOrderList(cookEvaluaOrder);
        return getDataTable(list);
    }

    /**
     * 导出订单评价列表
     */
    @ApiOperation(value = "导出订单评价列表")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:order:export")
    @SysLog(title = "订单评价", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出订单评价")
    @PostMapping("/export")
    public void export(HttpServletResponse response, CookEvaluaOrder cookEvaluaOrder) {
        List<CookEvaluaOrder> list = cookEvaluaOrderService.selectCookEvaluaOrderList(cookEvaluaOrder);
        ExcelUtil<CookEvaluaOrder> util = new ExcelUtil<CookEvaluaOrder>(CookEvaluaOrder.class);
        util.exportExcel(response, list, "订单评价数据");
    }

    /**
     * 获取订单评价详细信息
     */
    @ApiOperation(value = "获取订单评价详细信息")
    //@RequiresPermissions("cook:order:query")
    @GetMapping(value = "/{evaluaId}")
    public AjaxResult getInfo(@PathVariable("evaluaId") Long evaluaId) {
        return success(cookEvaluaOrderService.selectCookEvaluaOrderByEvaluaId(evaluaId));
    }

    /**
     * 新增订单评价
     */
    @ApiOperation(value = "新增订单评价")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:order:add")
    @SysLog(title = "订单评价", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增订单评价")
    @PostMapping
    public AjaxResult add(@RequestBody CookEvaluaOrder cookEvaluaOrder) {
        try {
            return toAjax(cookEvaluaOrderService.insertCookEvaluaOrder(cookEvaluaOrder));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 修改订单评价
     */
    @ApiOperation(value = "修改订单评价")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:order:edit")
    @SysLog(title = "订单评价", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改订单评价")
    @PostMapping("/edit")
    public AjaxResult edit(@RequestBody CookEvaluaOrder cookEvaluaOrder) {
        try {
            return toAjax(cookEvaluaOrderService.updateCookEvaluaOrder(cookEvaluaOrder));
        } catch (Exception e) {
            return error(e.getMessage());
        }
    }

    /**
     * 删除订单评价
     */
    @ApiOperation(value = "删除订单评价")
    //@PreventRepeatSubmit
    //@RequiresPermissions("cook:order:remove")
    @SysLog(title = "订单评价", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除订单评价")
	@PostMapping("/del/{evaluaIds}")
    public AjaxResult remove(@PathVariable Long[] evaluaIds) {
        return toAjax(cookEvaluaOrderService.deleteCookEvaluaOrderByEvaluaIds(evaluaIds));
    }
}
